# casual_inference

[![ci](https://github.com/shyaginuma/casual_inference/actions/workflows/config.yml/badge.svg)](https://github.com/shyaginuma/casual_inference/actions/workflows/config.yml)

Do A/B test analysis more easily.

## Awesome resources related to Experimenation

TBA
